@@ -27,6 +27,9 @@ class Settings:
     * `SKIP_TOKENS`
     * `NORMALIZE`
     * `RETURN_TIME_AS_PERIOD`
+    * `RETURN_TIME_SPAN`
+    * `DEFAULT_START_OF_WEEK`
+    * `DEFAULT_DAYS_IN_MONTH`
     * `PARSERS`
     * `DEFAULT_LANGUAGES`
     * `LANGUAGE_DETECTION_CONFIDENCE_THRESHOLD`
@@ -229,6 +232,14 @@ def check_settings(settings):
         "CACHE_SIZE_LIMIT": {
             "type": int,
         },
+        "RETURN_TIME_SPAN": {"type": bool},
+        "DEFAULT_START_OF_WEEK": {
+            "values": ("monday", "sunday"),
+            "type": str,
+        },
+        "DEFAULT_DAYS_IN_MONTH": {
+            "type": int,
+        },
     }
 
     modified_settings = settings._mod_settings  # check only modified settings
@@ -243,7 +254,7 @@ def check_settings(settings):
         setting_props = settings_values[setting_name]
 
         # check type:
-        if not setting_type == setting_props["type"]:
+        if not isinstance(setting_value, setting_props["type"]):
             raise SettingValidationError(
                 '"{}" must be "{}", not "{}".'.format(
                     setting_name, setting_props["type"].__name__, setting_type.__name__
